@@ -17,10 +17,18 @@
 
 #include "abstractfilelisting.h"
 
+#include "config-upnp-qt.h"
+
+#include "abstractfile/indexercommon.h"
+
 #include "musicaudiotrack.h"
 #include "notificationitem.h"
 #include "filescanner.h"
 
+#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
+#include <KFileMetaData/EmbeddedImageData>
+#endif
+
 #include <QThread>
 #include <QHash>
 #include <QFileInfo>
@@ -42,9 +50,7 @@ class AbstractFileListingPrivate
 {
 public:
 
-    explicit AbstractFileListingPrivate(QString sourceName) : mSourceName(std::move(sourceName))
-    {
-    }
+    QStringList mAllRootPaths;
 
     QFileSystemWatcher mFileSystemWatcher;
 
@@ -52,12 +58,14 @@ public:
 
     QHash<QUrl, QSet<QPair<QUrl, bool>>> mDiscoveredFiles;
 
-    QString mSourceName;
-
     FileScanner mFileScanner;
 
     QMimeDatabase mMimeDb;
 
+#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
+    KFileMetaData::EmbeddedImageData mImageScanner;
+#endif
+
     QHash<QUrl, QDateTime> mAllFiles;
 
     QAtomicInt mStopRequest = 0;
@@ -70,9 +78,13 @@ public:
 
     bool mHandleNewFiles = true;
 
+    bool mWaitEndTrackRemoval = false;
+
+    bool mErrorWatchingFileSystemChanges = false;
+
 };
 
-AbstractFileListing::AbstractFileListing(const QString &sourceName, QObject *parent) : QObject(parent), d(std::make_unique<AbstractFileListingPrivate>(sourceName))
+AbstractFileListing::AbstractFileListing(QObject *parent) : QObject(parent), d(std::make_unique<AbstractFileListingPrivate>())
 {
     connect(&d->mFileSystemWatcher, &QFileSystemWatcher::directoryChanged,
             this, &AbstractFileListing::directoryChanged);
@@ -85,24 +97,44 @@ AbstractFileListing::~AbstractFileListing()
 
 void AbstractFileListing::init()
 {
-    Q_EMIT askRestoredTracks(sourceName());
+    Q_EMIT askRestoredTracks();
 }
 
 void AbstractFileListing::newTrackFile(const MusicAudioTrack &partialTrack)
 {
-    const auto &newTrack = scanOneFile(partialTrack.resourceURI());
+    auto scanFileInfo = QFileInfo(partialTrack.resourceURI().toLocalFile());
+    const auto &newTrack = scanOneFile(partialTrack.resourceURI(), scanFileInfo);
 
     if (newTrack.isValid() && newTrack != partialTrack) {
-        Q_EMIT modifyTracksList({newTrack}, d->mAllAlbumCover, d->mSourceName);
+        Q_EMIT modifyTracksList({newTrack}, d->mAllAlbumCover);
     }
 }
 
-void AbstractFileListing::restoredTracks(const QString &musicSource, QHash<QUrl, QDateTime> allFiles)
+void AbstractFileListing::restoredTracks(QHash<QUrl, QDateTime> allFiles)
 {
-    if (musicSource == sourceName()) {
-        executeInit(std::move(allFiles));
+    executeInit(std::move(allFiles));
 
-        refreshContent();
+    refreshContent();
+}
+
+void AbstractFileListing::setAllRootPaths(const QStringList &allRootPaths)
+{
+    if (d->mAllRootPaths == allRootPaths) {
+        return;
+    }
+
+    d->mAllRootPaths = allRootPaths;
+}
+
+void AbstractFileListing::databaseFinishedInsertingTracksList()
+{
+}
+
+void AbstractFileListing::databaseFinishedRemovingTracksList()
+{
+    if (waitEndTrackRemoval()) {
+        Q_EMIT indexingFinished();
+        setWaitEndTrackRemoval(false);
     }
 }
 
@@ -111,6 +143,11 @@ void AbstractFileListing::applicationAboutToQuit()
     d->mStopRequest = 1;
 }
 
+const QStringList &AbstractFileListing::allRootPaths() const
+{
+    return d->mAllRootPaths;
+}
+
 void AbstractFileListing::scanDirectory(QList<MusicAudioTrack> &newFiles, const QUrl &path)
 {
     if (d->mStopRequest == 1) {
@@ -193,7 +230,7 @@ void AbstractFileListing::scanDirectory(QList<MusicAudioTrack> &newFiles, const
             continue;
         }
 
-        auto newTrack = scanOneFile(newFilePath);
+        auto newTrack = scanOneFile(newFilePath, oneEntry);
 
         if (newTrack.isValid() && d->mStopRequest == 0) {
             addCover(newTrack);
@@ -219,11 +256,6 @@ void AbstractFileListing::scanDirectory(QList<MusicAudioTrack> &newFiles, const
     }
 }
 
-const QString &AbstractFileListing::sourceName() const
-{
-    return d->mSourceName;
-}
-
 void AbstractFileListing::directoryChanged(const QString &path)
 {
     const auto directoryEntry = d->mDiscoveredFiles.find(QUrl::fromLocalFile(path));
@@ -240,12 +272,13 @@ void AbstractFileListing::directoryChanged(const QString &path)
 
 void AbstractFileListing::fileChanged(const QString &modifiedFileName)
 {
+    QFileInfo modifiedFileInfo(modifiedFileName);
     auto modifiedFile = QUrl::fromLocalFile(modifiedFileName);
 
-    auto modifiedTrack = scanOneFile(modifiedFile);
+    auto modifiedTrack = scanOneFile(modifiedFile, modifiedFileInfo);
 
     if (modifiedTrack.isValid()) {
-        Q_EMIT modifyTracksList({modifiedTrack}, d->mAllAlbumCover, d->mSourceName);
+        Q_EMIT modifyTracksList({modifiedTrack}, d->mAllAlbumCover);
     }
 }
 
@@ -264,10 +297,12 @@ void AbstractFileListing::refreshContent()
     triggerRefreshOfContent();
 }
 
-MusicAudioTrack AbstractFileListing::scanOneFile(const QUrl &scanFile)
+MusicAudioTrack AbstractFileListing::scanOneFile(const QUrl &scanFile, const QFileInfo &scanFileInfo)
 {
     MusicAudioTrack newTrack;
 
+    qCDebug(orgKdeElisaIndexer) << "AbstractFileListing::scanOneFile" << scanFile;
+
     auto localFileName = scanFile.toLocalFile();
 
     const auto &fileMimeType = d->mMimeDb.mimeTypeForFile(localFileName);
@@ -275,8 +310,6 @@ MusicAudioTrack AbstractFileListing::scanOneFile(const QUrl &scanFile)
         return newTrack;
     }
 
-    QFileInfo scanFileInfo(localFileName);
-
     if (scanFileInfo.exists()) {
         auto itExistingFile = d->mAllFiles.find(scanFile);
         if (itExistingFile != d->mAllFiles.end()) {
@@ -290,6 +323,7 @@ MusicAudioTrack AbstractFileListing::scanOneFile(const QUrl &scanFile)
     newTrack = d->mFileScanner.scanOneFile(scanFile, d->mMimeDb);
 
     if (newTrack.isValid()) {
+        newTrack.setHasEmbeddedCover(checkEmbeddedCoverImage(localFileName));
         newTrack.setFileModificationTime(scanFileInfo.fileTime(QFile::FileModificationTime));
 
         if (scanFileInfo.exists()) {
@@ -303,9 +337,12 @@ MusicAudioTrack AbstractFileListing::scanOneFile(const QUrl &scanFile)
 void AbstractFileListing::watchPath(const QString &pathName)
 {
     if (!d->mFileSystemWatcher.addPath(pathName)) {
-        Q_EMIT errorWatchingFiles();
+        qCDebug(orgKdeElisaIndexer) << "AbstractFileListing::watchPath" << "fail for" << pathName;
 
-        qDebug() << "AbstractFileListing::watchPath" << "fail for" << pathName;
+        if (!d->mErrorWatchingFileSystemChanges) {
+            d->mErrorWatchingFileSystemChanges = true;
+            Q_EMIT errorWatchingFileSystemChanges();
+        }
     }
 }
 
@@ -353,7 +390,7 @@ void AbstractFileListing::setHandleNewFiles(bool handleThem)
 
 void AbstractFileListing::emitNewFiles(const QList<MusicAudioTrack> &tracks)
 {
-    Q_EMIT tracksList(tracks, d->mAllAlbumCover, d->mSourceName);
+    Q_EMIT tracksList(tracks, d->mAllAlbumCover);
 }
 
 void AbstractFileListing::addCover(const MusicAudioTrack &newTrack)
@@ -413,11 +450,6 @@ void AbstractFileListing::removeFile(const QUrl &oneRemovedTrack, QList<QUrl> &a
     }
 }
 
-void AbstractFileListing::setSourceName(const QString &name)
-{
-    d->mSourceName = name;
-}
-
 QHash<QUrl, QDateTime> &AbstractFileListing::allFiles()
 {
     return d->mAllFiles;
@@ -432,6 +464,7 @@ void AbstractFileListing::checkFilesToRemove()
     }
 
     if (!allRemovedFiles.isEmpty()) {
+        setWaitEndTrackRemoval(true);
         Q_EMIT removedTracksList(allRemovedFiles);
     }
 }
@@ -441,5 +474,35 @@ FileScanner &AbstractFileListing::fileScanner()
     return d->mFileScanner;
 }
 
+bool AbstractFileListing::checkEmbeddedCoverImage(const QString &localFileName)
+{
+#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
+    auto imageData = d->mImageScanner.imageData(localFileName);
+
+    if (imageData.contains(KFileMetaData::EmbeddedImageData::FrontCover)) {
+        if (!imageData[KFileMetaData::EmbeddedImageData::FrontCover].isEmpty()) {
+            return true;
+        }
+    }
+#endif
+
+    return false;
+}
+
+bool AbstractFileListing::waitEndTrackRemoval() const
+{
+    return d->mWaitEndTrackRemoval;
+}
+
+void AbstractFileListing::setWaitEndTrackRemoval(bool wait)
+{
+    d->mWaitEndTrackRemoval = wait;
+}
+
+const QMimeDatabase &AbstractFileListing::mimeDatabase() const
+{
+    return d->mMimeDb;
+}
+
 
 #include "moc_abstractfilelisting.cpp"
