@@ -57,10 +57,6 @@ public Q_SLOTS:
 
     void serviceUnregistered(const QString &serviceName);
 
-    void fixBalooConfiguration();
-
-    void disableBalooIndexer();
-
 private Q_SLOTS:
 
     void newBalooFile(const QString &fileName);
@@ -77,9 +73,7 @@ private:
 
     void triggerRefreshOfContent() override;
 
-    MusicAudioTrack scanOneFile(const QUrl &scanFile) override;
-
-    bool checkBalooConfiguration();
+    MusicAudioTrack scanOneFile(const QUrl &scanFile, const QFileInfo &scanFileInfo) override;
 
     std::unique_ptr<LocalBalooFileListingPrivate> d;
 
