@@ -36,6 +36,7 @@
 #endif
 
 #include <QFileInfo>
+#include <QLocale>
 
 class FileScannerPrivate
 {
@@ -45,6 +46,8 @@ public:
     KFileMetaData::ExtractorCollection mAllExtractors;
 
     KFileMetaData::PropertyMap mAllProperties;
+
+    QString checkForMultipleEntries(KFileMetaData::Property::Property property);
 #endif
 
 };
@@ -112,31 +115,50 @@ void FileScanner::scanProperties(const Baloo::File &match, MusicAudioTrack &trac
 void FileScanner::scanProperties(const QString &localFileName, MusicAudioTrack &trackData)
 {
 #if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
+    auto artistString = d->checkForMultipleEntries(KFileMetaData::Property::Artist);
+    auto albumArtistString = d->checkForMultipleEntries(KFileMetaData::Property::AlbumArtist);
+    auto genreString = d->checkForMultipleEntries(KFileMetaData::Property::Genre);
+    auto composerString = d->checkForMultipleEntries(KFileMetaData::Property::Composer);
+    auto lyricistString = d->checkForMultipleEntries(KFileMetaData::Property::Lyricist);
+
     auto titleProperty = d->mAllProperties.find(KFileMetaData::Property::Title);
     auto durationProperty = d->mAllProperties.find(KFileMetaData::Property::Duration);
-    auto artistProperty = d->mAllProperties.find(KFileMetaData::Property::Artist);
     auto albumProperty = d->mAllProperties.find(KFileMetaData::Property::Album);
-    auto albumArtistProperty = d->mAllProperties.find(KFileMetaData::Property::AlbumArtist);
     auto trackNumberProperty = d->mAllProperties.find(KFileMetaData::Property::TrackNumber);
     auto discNumberProperty = d->mAllProperties.find(KFileMetaData::Property::DiscNumber);
-    auto genreProperty = d->mAllProperties.find(KFileMetaData::Property::Genre);
     auto yearProperty = d->mAllProperties.find(KFileMetaData::Property::ReleaseYear);
-    auto composerProperty = d->mAllProperties.find(KFileMetaData::Property::Composer);
-    auto lyricistProperty = d->mAllProperties.find(KFileMetaData::Property::Lyricist);
+    auto lyricsProperty = d->mAllProperties.find(KFileMetaData::Property::Lyrics);
     auto channelsProperty = d->mAllProperties.find(KFileMetaData::Property::Channels);
     auto bitRateProperty = d->mAllProperties.find(KFileMetaData::Property::BitRate);
     auto sampleRateProperty = d->mAllProperties.find(KFileMetaData::Property::SampleRate);
     auto commentProperty = d->mAllProperties.find(KFileMetaData::Property::Comment);
+    auto ratingProperty = d->mAllProperties.find(KFileMetaData::Property::Rating);
 #if !defined Q_OS_ANDROID
     auto fileData = KFileMetaData::UserMetaData(localFileName);
 #endif
 
-    if (albumProperty != d->mAllProperties.end()) {
-        trackData.setAlbumName(albumProperty->toString());
+    if (!artistString.isEmpty()) {
+        trackData.setArtist(artistString);
     }
 
-    if (artistProperty != d->mAllProperties.end()) {
-        trackData.setArtist(artistProperty->toStringList().join(QStringLiteral(", ")));
+    if (!albumArtistString.isEmpty()) {
+        trackData.setAlbumArtist(albumArtistString);
+    }
+
+    if (!genreString.isEmpty()) {
+        trackData.setGenre(genreString);
+    }
+
+    if (!composerString.isEmpty()) {
+        trackData.setComposer(composerString);
+    }
+
+    if (!lyricistString.isEmpty()) {
+        trackData.setLyricist(lyricistString);
+    }
+
+    if (albumProperty != d->mAllProperties.end()) {
+        trackData.setAlbumName(albumProperty->toString());
     }
 
     if (durationProperty != d->mAllProperties.end()) {
@@ -153,12 +175,6 @@ void FileScanner::scanProperties(const QString &localFileName, MusicAudioTrack &
 
     if (discNumberProperty != d->mAllProperties.end()) {
         trackData.setDiscNumber(discNumberProperty->toInt());
-    } else {
-        trackData.setDiscNumber(1);
-    }
-
-    if (albumArtistProperty != d->mAllProperties.end()) {
-        trackData.setAlbumArtist(albumArtistProperty->toStringList().join(QStringLiteral(", ")));
     }
 
     if (yearProperty != d->mAllProperties.end()) {
@@ -177,20 +193,8 @@ void FileScanner::scanProperties(const QString &localFileName, MusicAudioTrack &
         trackData.setSampleRate(sampleRateProperty->toInt());
     }
 
-    if (genreProperty != d->mAllProperties.end()) {
-        trackData.setGenre(genreProperty->toStringList().join(QStringLiteral(", ")));
-    }
-
-    if (composerProperty != d->mAllProperties.end()) {
-        trackData.setComposer(composerProperty->toStringList().join(QStringLiteral(", ")));
-    }
-
-    if (lyricistProperty != d->mAllProperties.end()) {
-        trackData.setLyricist(lyricistProperty->toStringList().join(QStringLiteral(", ")));
-    }
-
-    if (commentProperty != d->mAllProperties.end()) {
-        trackData.setComment(commentProperty->toString());
+    if (lyricsProperty != d->mAllProperties.end()) {
+        trackData.setLyrics(lyricsProperty->toString());
     }
 
     if (trackData.artist().isEmpty()) {
@@ -198,9 +202,31 @@ void FileScanner::scanProperties(const QString &localFileName, MusicAudioTrack &
     }
 
 #if !defined Q_OS_ANDROID
-    trackData.setRating(fileData.rating());
+    QString comment = fileData.userComment();
+    if (!comment.isEmpty()) {
+        trackData.setComment(comment);
+    } else if (commentProperty != d->mAllProperties.end()) {
+        trackData.setComment(commentProperty->toString());
+    }
+
+    int rating = fileData.rating();
+    if (rating > 0) {
+        trackData.setRating(rating);
+    } else if (ratingProperty != d->mAllProperties.end()) {
+        trackData.setRating(ratingProperty->toInt());
+    } else {
+        trackData.setRating(0);
+    }
 #else
-    trackData.setRating(0);
+    if (ratingProperty != d->mAllProperties.end()) {
+        trackData.setRating(ratingProperty->toInt());
+    } else {
+        trackData.setRating(0);
+    }
+
+    if (commentProperty != d->mAllProperties.end()) {
+        trackData.setComment(commentProperty->toString());
+    }
 #endif
 
     if (!trackData.duration().isValid()) {
@@ -213,3 +239,25 @@ void FileScanner::scanProperties(const QString &localFileName, MusicAudioTrack &
     Q_UNUSED(trackData)
 #endif
 }
+
+#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
+QString FileScannerPrivate::checkForMultipleEntries(KFileMetaData::Property::Property property)
+{
+    if (mAllProperties.count(property) > 1)  {
+        auto propertyList = mAllProperties.values(property);
+        return QLocale().createSeparatedList(QVariant(propertyList).toStringList());
+    } else {
+        auto variantResult = mAllProperties.find(property);
+        if (variantResult != mAllProperties.end()) {
+            auto value = variantResult.value();
+            if (value.type() == QVariant::List || value.type() == QVariant::StringList) {
+                return QLocale().createSeparatedList(value.toStringList());
+            } else {
+                return value.toString();
+            }
+        } else {
+            return QString();
+        }
+    }
+}
+#endif
