@@ -25,16 +25,14 @@
 
 #include <QStandardPaths>
 
-K_PLUGIN_FACTORY_WITH_JSON(KCMElisaLocalFileFactory,
-                           "kcm_elisa_local_file.json",
-                           registerPlugin<KCMElisaLocalFile>();)
+K_PLUGIN_CLASS_WITH_JSON(KCMElisaLocalFile, "kcm_elisa_local_file.json")
 
 KCMElisaLocalFile::KCMElisaLocalFile(QObject* parent, const QVariantList &args)
     : ConfigModule(parent, args)
 {
     KAboutData *about = new KAboutData(QStringLiteral("kcm_elisa_local_file"),
                                        i18n("Elisa Local Files Indexer Configuration"),
-                                       QStringLiteral("0.1"), {}, KAboutLicense::LGPL_V3,
+                                       QStringLiteral("0.3.80"), {}, KAboutLicense::LGPL_V3,
                                        i18n("Copyright 2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>"));
 
     about->addAuthor(i18n("Matthieu Gallien"),i18n("Author"), QStringLiteral("mgallien@mgallien.fr"));
