@@ -56,6 +56,10 @@
 #include <QQuickStyle>
 #include <QScreen>
 
+#if defined Qt5AndroidExtras_FOUND && Qt5AndroidExtras_FOUND
+#include <QAndroidService>
+#endif
+
 #include <memory>
 
 #if defined Qt5AndroidExtras_FOUND && Qt5AndroidExtras_FOUND
@@ -69,12 +73,34 @@ int __attribute__((visibility("default"))) main(int argc, char *argv[])
 int main(int argc, char *argv[])
 #endif
 {
+#if defined Q_OS_ANDROID
+    if(argc > 1 && strcmp(argv[1], "-service") == 0){
+        QAndroidService app(argc, argv);
+        qInfo() << "Service starting...";
+
+        // My service stuff
+
+        return app.exec();
+    }
+
+    qInfo() << "Application starting...";
+#endif
+
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
 
     qputenv("QT_GSTREAMER_USE_PLAYBIN_VOLUME", "true");
 
     QApplication app(argc, argv);
 
+#if defined Qt5AndroidExtras_FOUND && Qt5AndroidExtras_FOUND
+    qInfo() << QCoreApplication::arguments();
+
+    QAndroidJniObject::callStaticMethod<void>("org/kde/elisa/ElisaService",
+                                              "startMyService",
+                                              "(Landroid/content/Context;)V",
+                                              QtAndroid::androidContext().object());
+#endif
+
 #if defined KF5Crash_FOUND && KF5Crash_FOUND
     KCrash::initialize();
 #endif
@@ -85,7 +111,7 @@ int main(int argc, char *argv[])
 
     KAboutData aboutData( QStringLiteral("elisa"),
                           i18n("Elisa"),
-                          QStringLiteral("0.3.0"),
+                          QStringLiteral("0.3.80"),
                           i18n("A Simple Music Player written with KDE Frameworks"),
                           KAboutLicense::LGPL_V3,
                           i18n("(c) 2015-2018, Elisa contributors"));
@@ -109,15 +135,6 @@ int main(int argc, char *argv[])
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
-#if defined Qt5AndroidExtras_FOUND && Qt5AndroidExtras_FOUND
-    qDebug() << QCoreApplication::arguments();
-
-    QAndroidJniObject::callStaticMethod<void>("com/kde/elisa/ElisaService",
-                                              "startMyService",
-                                              "(Landroid/content/Context;)V",
-                                              QtAndroid::androidContext().object());
-#endif
-
     QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     QQuickStyle::setFallbackStyle(QStringLiteral("Fusion"));
 
@@ -147,7 +164,14 @@ int main(int argc, char *argv[])
     QObject::connect(&elisaService, &KDBusService::openRequested, myApp.get(), &ElisaApplication::openRequested);
 #endif
 
-    myApp->setArguments(parser.positionalArguments());
+    auto arguments = ElisaUtils::EntryDataList{};
+    auto realArgumentsList = parser.positionalArguments();
+
+    for (auto oneArgument : realArgumentsList) {
+        arguments.push_back(ElisaUtils::EntryData{0, oneArgument});
+    }
+
+    myApp->setArguments(arguments);
 
     engine.rootContext()->setContextProperty(QStringLiteral("elisa"), myApp.release());
 
