@@ -42,7 +42,10 @@ static const double MIN_RATE = 1.0;
 MediaPlayer2Player::MediaPlayer2Player(MediaPlayList *playListControler, ManageAudioPlayer *manageAudioPlayer,
                                        ManageMediaPlayerControl *manageMediaPlayerControl, ManageHeaderBar *manageHeaderBar, AudioWrapper *audioPlayer, QObject* parent)
     : QDBusAbstractAdaptor(parent), m_playListControler(playListControler), m_manageAudioPlayer(manageAudioPlayer),
-      m_manageMediaPlayerControl(manageMediaPlayerControl), m_manageHeaderBar(manageHeaderBar), m_audioPlayer(audioPlayer)
+      m_manageMediaPlayerControl(manageMediaPlayerControl), m_manageHeaderBar(manageHeaderBar), m_audioPlayer(audioPlayer),
+      mProgressIndicatorSignal(QDBusMessage::createSignal(QStringLiteral("/org/kde/elisa"),
+                                                          QStringLiteral("com.canonical.Unity.LauncherEntry"),
+                                                          QStringLiteral("Update")))
 {
     if (!m_playListControler) {
         return;
@@ -86,14 +89,28 @@ QString MediaPlayer2Player::PlaybackStatus() const
         return result;
     }
 
-    if (m_manageAudioPlayer->playerPlaybackState() == ManageAudioPlayer::StoppedState) {
+    if (m_manageAudioPlayer->playerPlaybackState() == QMediaPlayer::StoppedState) {
         result = QStringLiteral("Stopped");
-    } else if (m_manageAudioPlayer->playerPlaybackState() == ManageAudioPlayer::PlayingState) {
+    } else if (m_manageAudioPlayer->playerPlaybackState() == QMediaPlayer::PlayingState) {
         result = QStringLiteral("Playing");
     } else {
         result = QStringLiteral("Paused");
     }
 
+    QVariantMap parameters;
+
+    if (m_manageAudioPlayer->playerPlaybackState() == QMediaPlayer::StoppedState || m_audioPlayer->duration() == 0) {
+        parameters.insert(QStringLiteral("progress-visible"), false);
+        parameters.insert(QStringLiteral("progress"), 0);
+    } else {
+        parameters.insert(QStringLiteral("progress-visible"), true);
+        parameters.insert(QStringLiteral("progress"), qRound(static_cast<double>(m_position / m_audioPlayer->duration())) / 1000.0);
+    }
+
+    mProgressIndicatorSignal.setArguments({QStringLiteral("application://org.kde.elisa.desktop"), parameters});
+
+    QDBusConnection::sessionBus().send(mProgressIndicatorSignal);
+
     return result;
 }
 
@@ -198,6 +215,14 @@ void MediaPlayer2Player::setPropertyPosition(int newPositionInMs)
     signalPropertiesChange(QStringLiteral("Position"), Position());
 
     Q_EMIT Seeked(m_position);
+
+    QVariantMap parameters;
+    parameters.insert(QStringLiteral("progress-visible"), true);
+    parameters.insert(QStringLiteral("progress"), static_cast<double>(newPositionInMs) / m_audioPlayer->duration());
+
+    mProgressIndicatorSignal.setArguments({QStringLiteral("application://org.kde.elisa.desktop"), parameters});
+
+    QDBusConnection::sessionBus().send(mProgressIndicatorSignal);
 }
 
 double MediaPlayer2Player::Rate() const
@@ -207,7 +232,7 @@ double MediaPlayer2Player::Rate() const
 
 void MediaPlayer2Player::setRate(double newRate)
 {
-    if (newRate == 0) {
+    if (newRate <= 0.0001 && newRate >= -0.0001) {
         Pause();
     } else {
         m_rate = qBound(MinimumRate(), newRate, MaximumRate());
@@ -328,7 +353,7 @@ void MediaPlayer2Player::playerIsSeekableChanged()
 
 void MediaPlayer2Player::audioPositionChanged()
 {
-    setPropertyPosition(m_manageAudioPlayer->playerPosition());
+    setPropertyPosition(static_cast<int>(m_manageAudioPlayer->playerPosition()));
 }
 
 void MediaPlayer2Player::audioDurationChanged()
@@ -340,7 +365,7 @@ void MediaPlayer2Player::audioDurationChanged()
     skipForwardControlEnabledChanged();
     playerPlaybackStateChanged();
     playerIsSeekableChanged();
-    setPropertyPosition(m_manageAudioPlayer->playerPosition());
+    setPropertyPosition(static_cast<int>(m_manageAudioPlayer->playerPosition()));
 }
 
 void MediaPlayer2Player::playerVolumeChanged()
