@@ -20,14 +20,15 @@
 
 #include "elisaLib_export.h"
 
-#include <QObject>
-
+#include "databaseinterface.h"
 #include "musicaudiotrack.h"
+#include "elisautils.h"
+
+#include <QObject>
 
 #include <memory>
 
 class TracksListenerPrivate;
-class DatabaseInterface;
 
 class ELISALIB_EXPORT TracksListener : public QObject
 {
@@ -35,38 +36,50 @@ class ELISALIB_EXPORT TracksListener : public QObject
 
 public:
 
+    using ListTrackDataType = DatabaseInterface::ListTrackDataType;
+
+    using TrackDataType = DatabaseInterface::TrackDataType;
+
     explicit TracksListener(DatabaseInterface *database, QObject *parent = nullptr);
 
     ~TracksListener() override;
 
 Q_SIGNALS:
 
-    void trackHasChanged(const MusicAudioTrack &audioTrack);
+    void trackHasChanged(const TracksListener::TrackDataType &audioTrack);
 
     void trackHasBeenRemoved(qulonglong id);
 
-    void albumAdded(const QList<MusicAudioTrack> &tracks);
+    void tracksListAdded(qulonglong newDatabaseId,
+                         const QString &entryTitle,
+                         ElisaUtils::PlayListEntryType databaseIdType,
+                         const TracksListener::ListTrackDataType &tracks);
 
 public Q_SLOTS:
 
-    void tracksAdded(const QList<MusicAudioTrack> &allTracks);
+    void tracksAdded(const TracksListener::ListTrackDataType &allTracks);
 
     void trackRemoved(qulonglong id);
 
-    void trackModified(const MusicAudioTrack &modifiedTrack);
+    void trackModified(const TracksListener::TrackDataType &modifiedTrack);
 
     void trackByNameInList(const QString &title, const QString &artist, const QString &album, int trackNumber, int discNumber);
 
-    void trackByFileNameInList(const QUrl &fileName);
-
-    void trackByIdInList(qulonglong newTrackId);
-
-    void newArtistInList(const QString &artist);
+    void newEntryInList(qulonglong newDatabaseId,
+                        const QString &entryTitle,
+                        ElisaUtils::PlayListEntryType databaseIdType);
 
 private:
 
     MusicAudioTrack scanOneFile(const QUrl &scanFile);
 
+    void newArtistInList(qulonglong newDatabaseId, const QString &artist);
+
+    void trackByFileNameInList(const QUrl &fileName);
+
+    void newAlbumInList(qulonglong newDatabaseId,
+                        const QString &entryTitle);
+
     std::unique_ptr<TracksListenerPrivate> d;
 
 };
